@@ -358,6 +358,7 @@ class TopdeskConnector:
 			entry_type: str = "",
 			operator_name: str = "",
 			operator_group: str = "",
+			supplier_id: str = "",
 			category_name: str = "",
 			subcategory_name: str = "",
 			impact: str = "",
@@ -421,6 +422,10 @@ class TopdeskConnector:
 			body["operator"] = {
 				"name": f"{operator_name}"
 			}
+		if supplier_id:
+			body['supplier'] = {
+				'id': supplier_id
+			}
 
 		return self.make_request('post', 'incidents/', json_data=body)
 
@@ -446,6 +451,16 @@ class TopdeskConnector:
 		"""
 		return self.make_request('GET', 'suppliers/')
 
+	def supplier(self, id):
+		"""
+		Get information of a specific supplier determined by ID
+		Args:
+			id: supplier ID
+
+		Returns: supplier dict
+		"""
+		return self.make_request('GET', f'suppliers/{id}')
+
 	def suppliers_as_tuples(self):
 		"""
 		Get all supplier contacts as a list of tuples
@@ -471,6 +486,20 @@ class TopdeskConnector:
 		}
 		return self.make_request('get', 'operationalActivities', params=params).get('result')
 
+	def operational_activities_by_type(self, activity_type: str = None, ammount: int = 5) -> dict:
+		"""
+		Verkrijg een lijst van alle operationele activiteiten op basis van soort
+		Params
+			activity_type: Soort operationele activiteit.
+			ammount: hoeveelheid activiteiten om op te vragen.
+		Returns: Dict
+
+		"""
+		params = f"query=type.name=='{activity_type}'&pageSize={ammount}&fields=all"
+		headers = self.headers.copy()
+		headers['Accept'] = "application/x.topdesk-om-activity-v1+json"
+		return self.make_request('get', 'operationalActivities', params=params, headers=headers)
+
 	def operational_activity_with_status(self, activity_id: str) -> dict:
 		"""
 		Verkrijg informatie over 1 operational activity. Deze is specifiek gemaakt omdat er geen headers meegestuurd
